@@ -10,7 +10,9 @@
 ###############################################################################
 import json
 import os
+import re
 import shlex
+from glob import glob
 from os.path import join
 
 import click
@@ -250,36 +252,33 @@ def test(production_name, job_name, dependent_input, validate):
 
     # Validating Gaudi options
     test_ntuple_path = out_dir / f"00012345_00006789_1.{output_file}"
-
-    errors, warnings = [], []
-    if os.path.isfile(test_ntuple_path):
-        # TODO: This hasn't been updated to work with lb-prod-run
-        click.secho("Options parsing is currently unavailable", fg="yellow")
-        # if ".root" in test_ntuple_path.lower():
-        #     errors, warnings = do_options_parsing(
-        #         # TODO
-        #         env_cmd,
-        #         out_dir,
-        #         join(out_dir, "output.pkl"),
-        #         test_ntuple_path,
-        #         job_name,
-        #         prod_data,
-        #     )
-    elif any(
-        str(test_ntuple_path).lower() == join(out_dir, name).lower()
-        for name in out_dir.iterdir()
-    ):
-        warnings = [
-            "The output file has a different capitalisation to what is expected!"
-            " If this is a stripping job it could be due to a custom_stream"
-            " name not being written in all capital letters."
-        ]
+    for file_path in glob(str(out_dir / "*")):
+        if re.match(
+            str(test_ntuple_path),
+            file_path,
+            re.IGNORECASE,
+        ):
+            test_ntuple_path = file_path
+            break
     else:
         raise click.ClickException(
             "ERROR: The expected output file does not exist!\n"
             f"Expected: {test_ntuple_path}"
         )
 
+    errors, warnings = [], []
+    # TODO: This hasn't been updated to work with lb-prod-run
+    click.secho("Options parsing is currently unavailable", fg="yellow")
+    # if ".root" in test_ntuple_path.lower():
+    #     errors, warnings = do_options_parsing(
+    #         # TODO
+    #         env_cmd,
+    #         out_dir,
+    #         join(out_dir, "output.pkl"),
+    #         test_ntuple_path,
+    #         job_name,
+    #         prod_data,
+    #     )
     warnings.extend(yaml_warnings)
     for warning in warnings:
         click.secho(f"WARNING: {warning}", fg="yellow")
@@ -346,23 +345,26 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir, valida
 @click.argument("checks_data_file", type=str, nargs=1)
 @click.argument("input_ntuple", type=str, nargs=1)
 @click.argument("output_dir", type=str, nargs=1)
-def ci_checks(checks_data_file, input_ntuple, output_dir):
+@click.argument("job_index", type=int, nargs=1)
+def ci_checks(
+    checks_data_file: str, input_ntuple: str, output_dir: str, job_index: int
+):
     """Helper function for running checks in the CI. This is not recommended for users."""
     click.secho("Starting checks!", fg="green")
     with open(checks_data_file, "r") as inf:
         test_info = json.load(inf)
     check_results = run_job_checks(
-        test_info["jobs"][0]["checks"],
-        test_info["jobs"][0]["checks_data"],
+        test_info["jobs"][job_index]["checks"],
+        test_info["jobs"][job_index]["checks_data"],
         [input_ntuple],
     )
     hist_to_root(
-        test_info["jobs"][0]["name"], check_results, f"{output_dir}/checks.root"
+        test_info["jobs"][job_index]["name"], check_results, f"{output_dir}/checks.root"
     )
 
-    check_results = {test_info["jobs"][0]["name"]: check_results}
+    check_results = {test_info["jobs"][job_index]["name"]: check_results}
     checks_to_JSON(
-        test_info["jobs"][0]["checks_data"],
+        test_info["jobs"][job_index]["checks_data"],
         check_results,
         json_output_path=f"{output_dir}/checks.json",
     )
