@@ -11,6 +11,7 @@
 import glob
 import os
 import pathlib
+import re
 import subprocess
 import tempfile
 from concurrent.futures import ThreadPoolExecutor
@@ -162,10 +163,18 @@ def recursively_create_input(production_name, job_name, filetype, prod_data):
     )
 
     output_filetypes = [x.lower() for x in prod_data[job_name]["output"]]
-    if filetype.lower() not in output_filetypes:
-        raise NotImplementedError(
-            f"Looking for {filetype} but {job_name} only produces {output_filetypes}"
-        )
+    if filetype:
+        if filetype.lower() not in output_filetypes:
+            raise NotImplementedError(
+                f"Looking for {filetype} but {job_name} only produces {output_filetypes}"
+            )
+    else:
+        if len(output_filetypes) > 1:
+            raise ValueError(
+                "An input filetype must be specified when taking input from a multi-output job!"
+            )
+        else:
+            filetype = output_filetypes[0]
 
     # Run the job the desired job depends on
     result = logging_subprocess_run(
@@ -175,26 +184,21 @@ def recursively_create_input(production_name, job_name, filetype, prod_data):
     output_dir = result.split("\n")[-2].split(" ")[-1]
     # if this is False clearly some other error has occurred so don't bother continuing
     if os.path.exists(output_dir):
-        # Set the dependent input to lower case to handle inconsistencies between
-        # yaml definition and produced file
-        dependent_input = (
-            output_dir + f"/00012345_00006789_1.{filetype.lower()}"
-        ).lower()
-
-        # Set up a dictionary to map lower case output file names to their
-        # actual file name locations
-        output_files_dict = {
-            join(output_dir, name).lower(): join(output_dir, name)
-            for name in os.listdir(output_dir)
-        }
-
-        # Check we have the desired output
-        if dependent_input not in output_files_dict:
+        dependent_input = output_dir + f"/00012345_00006789_1.{filetype}"
+        for file_path in glob.glob(f"{output_dir}/*"):
+            if re.match(
+                dependent_input,
+                file_path,
+                re.IGNORECASE,
+            ):
+                dependent_input = file_path
+                break
+        else:
             raise OSError(
                 f"{job_name} did not produce the desired output {dependent_input}"
             )
 
-        return output_files_dict[dependent_input]
+        return dependent_input
     else:
         raise OSError(
             f"The expected output directory {output_dir} does not exist! "
@@ -222,7 +226,7 @@ def resolve_input_overrides(prod_data, job_name):
             )
         else:
             raise NotImplementedError(
-                "Input requires either a bookkeeping location or a previous job name"
+                "Input requires either a bookkeeping location, transform ids or a previous job name"
             )
     return override_input, output_filetype
 
